# Moonshot
Moonshot is a vectorized backtesting and trading engine for [QuantRocket](https://www.quantrocket.com).

For installation and usage documentation, please visit: https://www.quantrocket.com/docs/#moonshot

## License

Moonshot is distributed under the Apache 2.0 License. See the LICENSE file in the release for details.
